CouplesState class

Annotations
  • @freezed

Constructors

CouplesState({required int size, @Default.new(false) bool isLoading, @Default.new(<String>[]) List<String?> items, @Default.new(<int>[]) List<int> openedIndexes})
const
factory

Properties

copyWith → $CouplesStateCopyWith<CouplesState>
Create a copy of CouplesState with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isLoading bool
no setterinherited
items List<String?>
no setterinherited
openedIndexes List<int>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited