RaAnswer class

Annotations
  • @freezed

Constructors

RaAnswer({required int id, required String title, required bool isCorrent, required int questionId})
const
factory
RaAnswer.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $RaAnswerCopyWith<RaAnswer>
Create a copy of RaAnswer with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
isCorrent bool
no setterinherited
questionId int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this RaAnswer to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited