AppMainTabsEnum enum

Inheritance
Available extensions

Values

home → const AppMainTabsEnum
const AppMainTabsEnum(0)
const AppMainTabsEnum(1)
stats → const AppMainTabsEnum
const AppMainTabsEnum(3)
profile → const AppMainTabsEnum
const AppMainTabsEnum(4)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
pageIndex int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AppMainTabsEnum>
A constant List of the values in this enum, in order of their declaration.