RaScreenState class

Annotations
  • @freezed

Constructors

RaScreenState({@Default.new(true) bool isLoading, RaAnswer? selectedAnswer, RaQuestion? question, @Default.new(<RaAnswer>[]) List<RaAnswer> answers, String? message, String? timer})
const
factory

Properties

answers List<RaAnswer>
no setterinherited
copyWith → $RaScreenStateCopyWith<RaScreenState>
Create a copy of RaScreenState with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isLoading bool
no setterinherited
message String?
no setterinherited
question RaQuestion?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedAnswer RaAnswer?
no setterinherited
timer String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited